@@ -36,11 +36,11 @@ makeHighlightWeaveLatexCodeRunner <- function(evalFunc=RweaveEvalWithOpt, highli
     HighlightWeaveLatexRuncode <- function(object, chunk, options) {
       	  
       	  if( "lang" %in% names(options)){
-      	  	  if( isTRUE( private[["has_highlight"]] )){
+      	  	  if( private[["has_highlight"]] ){
       	  	  	  tf <- sprintf( "%s.%s", tempfile(), options$lang )
       	  	  		writeLines( chunk, tf )
       	  	  		tf2 <- tempfile()
-      	  	  		cmd <- sprintf( 'highlight --input="%s" --output="%s" -L --pretty-symbols', tf, tf2 )
+      	  	  		cmd <- sprintf( '%s --input="%s" --output="%s" -L --pretty-symbols', shQuote(private[["highlight"]]), tf, tf2 )
       	  	  		system( cmd )
       	  	  		tex <- readLines(tf2) 
       	  	  		keep <- seq( which( tex == "\\noindent" ), which( tex == "\\normalfont" ) )
@@ -165,13 +165,14 @@ makeHighlightWeaveLatexCodeRunner <- function(evalFunc=RweaveEvalWithOpt, highli
 						cat("\\begin{Hinput}",
 							file=chunkout, append=TRUE)
 						cat("\n", file = chunkout, append = TRUE )
+						showPrompts <- options$prompt
 						highlight( output = chunkout, 
 		 					parser.output = parser.output, 
 		 					styles = styles, 
 		 					expr = nce, 
 		 					renderer = renderer, 
 							final.newline = FALSE, 
-							showPrompts = TRUE, 
+							showPrompts = if( !is.null(showPrompts) ) isTRUE(showPrompts) else TRUE , 
 							initial.spaces = FALSE )
 						cat("\n\\end{Hinput}\n", file=chunkout, append=TRUE)
 	                   
